TheCannon
=========

This is the code associated with *The Cannon*, a data-driven method for 
determining stellar labels (physical parameters and chemical abundances) from
stellar spectra in the context of large spectroscopic surveys. It closely 
follows the method outlined in Ness et al. 2015, although some minor changes 
have been made. A description of these changes is outlined in Ho et al. 2016 (arXiv:1602.00303).

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.221367.svg
   :target: https://doi.org/10.5281/zenodo.221367

Documentation for The Cannon can be found here_. 

.. _here: https://annayqho.github.io/TheCannon/

Authors
-------

* **Anna Ho** (MPIA)
* **Melissa Ness** (MPIA)
* **David W. Hogg** (SCDA NYU MPIA)
* **Hans-Walter Rix** (MPIA)

License and Citation
--------------------

Copyright 2015 the authors. TheCannon is open-source software released under 
the MIT License. See the file ``LICENSE`` for details.

A condition on using this code for any academic purpose is citation of
Ness et al. 2015 (arXiv:1501.07604) and Ho et al. 2016 (arXiv:1602.00303). 

Projects
--------

* Label Transfer from APOGEE to LAMOST: Precise Stellar Parameters for 450,000 LAMOST Giants
* Masses and Ages for 230,000 LAMOST Giants, via Their Carbon and Nitrogen Abundances
